from django.conf import settings
from django.core.mail import EmailMultiAlternatives
from django.template.loader import render_to_string
from django.utils.translation import ugettext

from notification import backends


class EmailBackend(backends.BaseBackend):
    spam_sensitivity = 2
    
    def can_send(self, user, notice_type):
        can_send = super(EmailBackend, self).can_send(user, notice_type)
        if can_send and user.email:
            return True
        return False
        
    def deliver(self, recipient, sender, notice_type, extra_context):
        
        context = self.default_context()
        context.update({
            "recipient": recipient,
            "sender": sender,
            "notice": ugettext(notice_type.display),
        })
        context.update(extra_context)
        
        formats = [
            "short.txt",
            "full.txt",
            "full.html",
        ]
        messages = self.get_formatted_messages(
            formats, notice_type.label, context
        )
        
        ctx = {
            "message": messages["short.txt"],
        }
        subject = render_to_string("notification/email_subject.txt", ctx, context)
        subject = "".join(subject.splitlines())
        
        ctx = {
            "message": messages["full.txt"],
        }
        text_body = render_to_string("notification/email_body.txt", ctx, context)
        
        
        
        msg = EmailMultiAlternatives(
            subject,
            text_body,
            settings.DEFAULT_FROM_EMAIL,
            [recipient.email]
        )
        msg.attach_alternative(html_body, "text/html")
        msg.send()
